Expect Library — ATLAS 0.1 documentation

# Expect Library

The library that is used for output validation.

is_not_none(...)

  Validates whether the argument is None or not.

is_not_empty_list(...)

  Validates whether the list type argument is not empty.

is_not_empty_dict(...)

  Validates whether the dict type argument is not empty.

is_not_empty_str(...)

  Validates whether the str type argument is not empty.

is_pe(...)

  Validates whether the argument is ‘application/x-dosexec’ or not.